smartcard.Observer.Observable

# ``smartcard`.`Observer`.`Observable``

class documentation

`class Observable(Synchronization):`

Known subclasses: `smartcard.CardConnection.CardConnection`, `smartcard.ReaderMonitoring.ReaderMonitor`, `smartcard.CardMonitoring.CardMonitor.__CardMonitorSingleton`

View In Hierarchy

Undocumented

Method | `__init__` | Undocumented
Method | `addObserver` | Undocumented
Method | `clearChanged` | Undocumented
Method | `countObservers` | Undocumented
Method | `deleteObserver` | Undocumented
Method | `deleteObservers` | Undocumented
Method | `hasChanged` | Undocumented
Method | `notifyObservers` | If 'changed' indicates that this object has changed, notify all its observers, then call clearChanged(). Each observer has its update() called with two arguments: this observable object and the generic 'arg'.
Method | `setChanged` | Undocumented
Instance Variable | `changed` | Undocumented
Instance Variable | `obs` | Undocumented

Inherited from `Synchronization`:

Instance Variable | `mutex` | Undocumented

def __init__(self):
overrides `smartcard.Synchronization.Synchronization.__init__`
overridden in `smartcard.CardConnection.CardConnection`, `smartcard.ReaderMonitoring.ReaderMonitor`, `smartcard.CardMonitoring.CardMonitor.__CardMonitorSingleton`

Undocumented

def addObserver(self, observer):
overridden in `smartcard.CardConnection.CardConnection`, `smartcard.ReaderMonitoring.ReaderMonitor`, `smartcard.CardMonitoring.CardMonitor.__CardMonitorSingleton`

Undocumented

def clearChanged(self):

Undocumented

def countObservers(self):

Undocumented

def deleteObserver(self, observer):
overridden in `smartcard.CardConnection.CardConnection`, `smartcard.ReaderMonitoring.ReaderMonitor`, `smartcard.CardMonitoring.CardMonitor.__CardMonitorSingleton`

Undocumented

def deleteObservers(self):

Undocumented

def hasChanged(self):

Undocumented

def notifyObservers(self, arg=None):

If 'changed' indicates that this object has changed, notify all its observers, then call clearChanged(). Each observer has its update() called with two arguments: this observable object and the generic 'arg'.

def setChanged(self):

Undocumented

changed: `int` =

Undocumented

obs: `list` =

Undocumented